IncommeMaterialApp class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- IncommeMaterialApp
- Available extensions
Constructors
-
IncommeMaterialApp({Key? key, String title = '', String? initialRoute, Translations? translations, Locale? locale, Locale? fallbackLocale, Bindings? initialBinding, Transition? defaultTransition, List<
GetPage> ? getPages, GetPage? unknownRoute, Widget? home, CustomTransition? customTransition, bool? enableLog, LogWriterCallback? logWriterCallback, bool? popGesture, SmartManagement? smartManagement, bool? preventDuplicatePush, Transition? defaultGlobalTransition, Curve? defaultCurve, Duration? transitionDuration, TransitionBuilder? builder, ThemeData? theme, ThemeData? darkTheme, ThemeMode? themeMode, Iterable<LocalizationsDelegate> ? localizationsDelegates, Locale? localeResolutionCallback(Locale? locale, Iterable<Locale> supportedLocales)?, Iterable<Locale> ? supportedLocales, bool? debugShowCheckedModeBanner, Route? onUnknownRoute(RouteSettings settings)?, Route? onGenerateRoute(RouteSettings settings)?, Map<String, Widget Function(BuildContext context)> ? routes, Map<Type, Action< ? actions, bool? checkerboardOffscreenLayers, bool? checkerboardRasterCacheImages, Color? color, bool? debugShowMaterialGrid, bool? defaultGlobalState, ThemeData? highContrastDarkTheme, ThemeData? highContrastTheme, Locale? localeListResolutionCallback(List<Intent> >Locale> ? locales, Iterable<Locale> supportedLocales)?, void onDispose()?, List<Route> onGenerateInitialRoutes(String initialRoute)?, String onGenerateTitle(BuildContext context)?, void onInit()?, void onReady()?, bool? opaqueRoute, void routingCallback(Routing? value)?, GlobalKey<ScaffoldMessengerState> ? scaffoldMessengerKey, ScrollBehavior? scrollBehavior, Map<LogicalKeySet, Intent> ? shortcuts, bool? showPerformanceOverlay, bool? showSemanticsDebugger, TextDirection? textDirection, Map<String, Map< ? translationsKeys, bool? useInheritedMediaQuery})String, String> > -
const
Properties
-
actions
→ Map<
Type, Action< ?Intent> > -
final
- builder → TransitionBuilder?
-
final
- checkerboardOffscreenLayers → bool?
-
final
- checkerboardRasterCacheImages → bool?
-
final
- color → Color?
-
final
- customTransition → CustomTransition?
-
final
- darkTheme → ThemeData?
-
final
- debugShowCheckedModeBanner → bool?
-
final
- debugShowMaterialGrid → bool?
-
final
- defaultCurve → Curve?
-
final
- defaultGlobalState → bool?
-
final
- defaultGlobalTransition → Transition?
-
final
- defaultTransition → Transition?
-
final
- enableLog → bool?
-
final
- fallbackLocale → Locale?
-
final
-
getPages
→ List<
GetPage> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highContrastDarkTheme → ThemeData?
-
final
- highContrastTheme → ThemeData?
-
final
- home → Widget?
-
final
- initialBinding → Bindings?
-
final
- initialRoute → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → Locale?
-
final
-
localeListResolutionCallback
→ Locale? Function(List<
Locale> ? locales, Iterable<Locale> supportedLocales)? -
final
-
localeResolutionCallback
→ Locale? Function(Locale? locale, Iterable<
Locale> supportedLocales)? -
final
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> ? -
final
- logWriterCallback → LogWriterCallback?
-
final
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter -
final
-
final
- onDispose → void Function()?
-
final
-
onGenerateInitialRoutes
→ List<
Route> Function(String initialRoute)? -
final
- onGenerateRoute → Route? Function(RouteSettings settings)?
-
final
- onGenerateTitle → String Function(BuildContext context)?
-
final
- onInit → void Function()?
-
final
- onReady → void Function()?
-
final
- onUnknownRoute → Route? Function(RouteSettings settings)?
-
final
- opaqueRoute → bool?
-
final
- paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - popGesture → bool?
-
final
- preventDuplicatePush → bool?
-
final
-
routes
→ Map<
String, Widget Function(BuildContext context)> ? -
final
- routingCallback → void Function(Routing? value)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? -
final
- scrollBehavior → ScrollBehavior?
-
final
-
shortcuts
→ Map<
LogicalKeySet, Intent> ? -
final
- showPerformanceOverlay → bool?
-
final
- showSemanticsDebugger → bool?
-
final
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter - smartManagement → SmartManagement?
-
final
-
supportedLocales
→ Iterable<
Locale> ? -
final
- textDirection → TextDirection?
-
final
- theme → ThemeData?
-
final
- themeMode → ThemeMode?
-
final
- title → String
-
final
- transitionDuration → Duration?
-
final
- translations → Translations?
-
final
-
translationsKeys
→ Map<
String, Map< ?String, String> > -
final
- unknownRoute → GetPage?
-
final
- useInheritedMediaQuery → bool?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited