components/lazy_load library

Classes

LazyLoad
A widget that wraps a Widget and will trigger onEndOfPage when it reaches the bottom of the list
LazyLoadState

Typedefs

EndOfPageListenerCallback = void Function()
Signature for EndOfPageListeners