LazyLoad class

A widget that wraps a Widget and will trigger onEndOfPage when it reaches the bottom of the list

Inheritance
Available extensions

Constructors

LazyLoad({Key? key, required Widget child, required EndOfPageListenerCallback onEndOfPage, Axis scrollDirection = Axis.vertical, bool isLoading = false, int scrollOffset = 100})
const

Properties

child Widget
The Widget that this widget watches for changes on
final
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
Used to determine if loading of new data has finished. You should use set this if you aren't using a FutureBuilder or StreamBuilder
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
onEndOfPage EndOfPageListenerCallback
Called when the child reaches the end of the list
final
paddingZero Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis
Prevented update nested listview with other axis direction
final
scrollOffset int
The offset to take into account when triggering onEndOfPage in pixels
final
sliverBox Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited