AppCacheKey class

Constructors

AppCacheKey()
const

Properties

accessToken String
no setter
authRefreshToken String
no setter
authToken String
no setter
branchId String
no setter
cartCoachMark String
no setter
csft String
no setter
fcm String
no setter
firstTime String
no setter
firstTimeScanInStore String
no setter
hashCode int
The hash code for this object.
no setterinherited
lastPromoDate String
no setter
listSub String
no setter
no setter
recentOfferSearch String
no setter
recentProductSearch String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user String
no setter
userId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited