HttpStatusCode class

Constructors

HttpStatusCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

badRequest → const int
forbiddenAccess → const int
internalServerError → const int
noConnection → const int
notFound → const int
requestTimeout → const int
success → const int
unauthorizedAccess → const int
unProcessableContent → const int