IncommeConstants class

Constructors

IncommeConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
svgAssets List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appApi AppApi
getter/setter pair
appCacheKey AppCacheKey
getter/setter pair
appRoute IncommeAppRoute
getter/setter pair
appSettings SettingCode
getter/setter pair

Constants

api1 → const String
api2 → const String
appIconPath → const String
appImagePath → const String
appName → const String
appVersion → const String
baseUrl → const String
buildNumber → const String
core → const String
corePackage → const String
devReleaseFlavor → const String
domain → const String
flavor → const String
isDebug → const String
merchantId → const String
msuFlavor → const String
msuUatFlavor → const String
passwordBasicAuth → const String
productionFlavor → const String
productionMid → const String
stagingFlavor → const String
stagingMid → const String
uatFlavor → const String
uatMid → const String
uiKit → const String
usernameBasicAuth → const String