menu
incomme_flutter_commerce package
documentation
core/common_entities/file_model.dart
FileModel class
FileModel class
dark_mode
light_mode
FileModel
class
Constructors
FileModel
({
String
?
fileName
,
String
?
fullPath
,
String
?
localPath
})
const
FileModel.map
(
Map
json
)
factory
Properties
fileName
→
String
final
fullPath
→
String
final
hashCode
→
int
The hash code for this object.
no setter
inherited
localPath
→
String
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
fileName
,
String
?
fullPath
,
String
?
localPath
})
→
FileModel
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
incomme_flutter_commerce package
documentation
core/common_entities/file_model
FileModel class
file_model library