Lookup class

Constructors

Lookup({bool? active, String? createdDate, String? modifiedDate, String? createdBy, String? modifiedBy, String? id, String? detailCode, String? meaning, String? description, String? shortDescription, bool? selected})
Lookup.map(Map obj)
factory

Properties

active bool
getter/setter pair
createdBy String
getter/setter pair
createdDate String
getter/setter pair
description String
getter/setter pair
detailCode String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
meaning String
getter/setter pair
modifiedBy String
getter/setter pair
modifiedDate String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pair
shortDescription String
getter/setter pair

Methods

copyWith({bool? active, String? createdDate, String? modifiedDate, String? createdBy, String? modifiedBy, String? id, String? detailCode, String? meaning, String? description, String? shortDescription, bool? selected}) Lookup
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited