LookupData class

Constructors

LookupData({bool? active, String? createdDate, String? modifiedDate, String? createdBy, String? modifiedBy, String? name, String? description, String? dataType, List<Lookup>? detail})
const
LookupData.map(Map obj)
factory

Properties

active bool
final
createdBy String
final
createdDate String
final
dataType String
final
description String
final
detail List<Lookup>
final
hashCode int
The hash code for this object.
no setterinherited
modifiedBy String
final
modifiedDate String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited