HistoryDataMapper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
mapReceiptBillingInformation(
ReceiptBillingInformationResp? resp) → ReceiptBillingInformation -
mapReceiptGiftCards(
ReceiptGiftCardsResp? resp) → ReceiptGiftCards -
mapReceiptGiftCertificates(
ReceiptGiftCertificatesResp? resp) → ReceiptGiftCertificates -
mapReceiptOrder(
ReceiptOrderResp? resp) → ReceiptOrder -
mapReceiptOrderDeliveries(
ReceiptOrderDeliveriesResp? resp, String? deliveryMethod, int? branchID, int? orderId) → ReceiptOrderDeliveries -
mapReceiptOrderDiscounts(
ReceiptOrderDiscountsResp? resp) → ReceiptOrderDiscounts -
mapReceiptOrderItemAttributes(
AttributesOptions? resp) → AttributesOptions -
mapReceiptOrderItems(
ReceiptOrderItemsResp? resp, String? deliveryMethod, int? branchID, int? orderId) → ReceiptOrderItems -
mapReceiptPaymentInformation(
ReceiptPaymentInformationResp? resp) → ReceiptPaymentInformation -
mapReceiptPaymentSummary(
ReceiptPaymentSummaryResp? resp) → ReceiptPaymentSummary -
mapReceiptSummary(
ReceiptSummaryResp? resp) → ReceiptSummary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited