ListPostalCodeDto class

Constructors

ListPostalCodeDto({bool? success, String? error, List<String>? errors, List<String>? errorCodes, List<String>? messages, List<String>? messageCodes, List<PostalCodeResponse>? jsonResult})
ListPostalCodeDto.map(Map<String, dynamic> obj)

Properties

error String?
getter/setter pair
errorCodes List<String>?
getter/setter pair
errors List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jsonResult List<PostalCodeResponse>?
getter/setter pair
messageCodes List<String>?
getter/setter pair
messages List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited