PostalCodeResponse class
Constructors
- PostalCodeResponse({int? districtID, String? districtName, int? subDistrictID, String? subDistrictName, int? postalCode})
- PostalCodeResponse.map(Map json)
Properties
- districtID ↔ int?
-
getter/setter pair
- districtName ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- postalCode ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subDistrictID ↔ int?
-
getter/setter pair
- subDistrictName ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited