OrderItems class

Constructors

OrderItems({int? orderItemId, double? total, double? quantity, String? seoCode, String? name, double? price, double? altPrice, String? image, int? productId, Flexi? flexi, int? skuID, String? skuCode, List<OrderItemAttributes>? orderItemAttributes, bool? isChecked, bool? isSoldOut, int? quantityRemain, bool? isFlexiSelection})
OrderItems.map(Map obj)
factory

Properties

altPrice double
getter/setter pair
canAdd bool
getter/setter pair
flexi Flexi
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image String
getter/setter pair
isChecked bool
getter/setter pair
isFlexiSelection bool
getter/setter pair
isSoldOut bool
getter/setter pair
name String
getter/setter pair
orderItemAttributes List<OrderItemAttributes>
getter/setter pair
orderItemId int
getter/setter pair
price double
getter/setter pair
productId int
getter/setter pair
quantity double
getter/setter pair
quantityRemain int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seoCode String
getter/setter pair
skuCode String
getter/setter pair
skuID int
getter/setter pair
total double
getter/setter pair

Methods

copyWith({int? orderItemId, double? total, double? quantity, String? seoCode, String? name, double? price, double? altPrice, String? image, int? productId, Flexi? flexi, int? skuID, String? skuCode, List<OrderItemAttributes>? orderItemAttributes, bool? isChecked, bool? isSoldOut, int? quantityRemain, bool? isFlexiSelection}) OrderItems
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited