AttributesOptions class

Constructors

AttributesOptions({String? attributeCode, String? attributeName, String? attributeValue, String? optionCode, String? optionName, List<AttributeOptionList>? options})
const
AttributesOptions.map(Map json)
factory

Properties

attributeCode String
final
attributeName String
final
attributeValue String
final
hashCode int
The hash code for this object.
no setterinherited
optionCode String
final
optionName String
final
options List<AttributeOptionList>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? attributeCode, String? attributeName, String? attributeValue, String? optionCode, String? optionName, List<AttributeOptionList>? options}) AttributesOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited