ShippingCoverageCheck class

Constructors

ShippingCoverageCheck({String? estimationDays, String? shippingDeliveryDays, String? price, int? anotherCoveredBranches, bool? isCovered})
const
ShippingCoverageCheck.map(Map map)
factory

Properties

anotherCoveredBranches int
final
estimationDays String
final
hashCode int
The hash code for this object.
no setterinherited
isCovered bool
final
price String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingDeliveryDays String
final

Methods

copyWith({String? estimationDays, String? shippingDeliveryDays, String? price, int? anotherCoveredBranches, bool? isCovered}) ShippingCoverageCheck
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited