Profile class

Constructors

Profile({String? firstName, String? lastName, String? phone, String? email, String? dob, String? imageProfile, String? referalCode, bool? verifiedEmail})
const
Profile.map(Map json)
factory

Properties

dob String
final
email String
final
firstName String
final
hashCode int
The hash code for this object.
no setterinherited
imageProfile String
final
lastName String
final
phone String
final
referalCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifiedEmail bool
final

Methods

copyWith({String? firstName, String? lastName, String? phone, String? email, String? dob, String? imageProfile, String? referalCode, bool? verifiedEmail}) Profile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited