ScanResult class

Constructors

ScanResult({required String barcodeType, required String codeCart, required String codeTransitPoin, required String codeVoucher, required String androidClick, required String apnsClick, required int productId, required String productCode, required int skuId, required DateTime currentTime})
const

Properties

androidClick String
final
apnsClick String
final
barcodeType String
final
codeCart String
final
codeTransitPoin String
final
codeVoucher String
final
currentTime DateTime
final
hashCode int
The hash code for this object.
no setterinherited
isNotFound bool
no setter
productCode String
final
productId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skuId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited