ShippingCoverage class
Constructors
- ShippingCoverage({String? estimationDays, String? shippingDeliveryDays, String? price, int? anotherCoveredBranches, bool? isCovered})
-
ShippingCoverage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- anotherCoveredBranches ↔ int
-
getter/setter pair
- estimationDays ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCovered ↔ bool
-
getter/setter pair
- price ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingDeliveryDays ↔ String
-
getter/setter pair
Methods
-
copyWith(
{String? estimationDays, String? shippingDeliveryDays, String? price, int? anotherCoveredBranches, bool? isCovered}) → ShippingCoverage -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited