Store class

Constructors

Store({int? storeId, String? store, String? picEmail, int? distance, int? qty, bool? isStockAvail, String? distanceText, String? address, ShippingCoverage? shippingCoverage})
Store.fromJson(Map<String, dynamic> json)
factory

Properties

address String
getter/setter pair
distance int
getter/setter pair
distanceText String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isStockAvail bool
getter/setter pair
picEmail String
getter/setter pair
qty int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingCoverage ShippingCoverage
getter/setter pair
store String
getter/setter pair
storeId int
getter/setter pair

Methods

copyWith({int? storeId, String? store, String? picEmail, int? distance, int? qty, bool? isStockAvail, String? distanceText, String? address, ShippingCoverage? shippingCoverage}) Store
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited