ValidateSdkUseCaseImpl class

Inheritance

Constructors

ValidateSdkUseCaseImpl({required ValidateSdkRepository repository})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
repository ValidateSdkRepository
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateSdkKey({required Map<String, dynamic> body}) Future<Either<IncommeError, ValidateSdkResponse>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited