GetPermission class

Constructors

GetPermission()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAndroidSdkInt() Future<int>
Get the current Android SDK version (fallback method)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestMedia(BuildContext context, PlatformPermisson source) Future
Request media access for the specified permission type
requestStoragePermission(BuildContext context) Future<bool>
Request storage permission specifically for file operations
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited