$AssetsImagesBackgroundGen class

Constructors

$AssetsImagesBackgroundGen()
const

Properties

bgCashback AssetGenImage
File path: assets/images/background/bg_cashback.png
no setter
bgHomeHeader SvgGenImage
File path: assets/images/background/bg_home_header.svg
no setter
bgProductDetail SvgGenImage
File path: assets/images/background/bg_product_detail.svg
no setter
hashCode int
The hash code for this object.
no setterinherited
ob1 AssetGenImage
File path: assets/images/background/ob1.png
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited