Incomme class

Constructors

Incomme()
factory

Properties

config IncommeConfig
no setter
context BuildContext?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateSdkUseCase ValidateSdkUseCase
getter/setter pair

Methods

initialize(IncommeConfig config, {BuildContext? context, dynamic onError(IncommeError)?, dynamic onSuccess(bool status)?}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateSdkKey() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appName String
no setter
no setter
fontFamilyName String
no setter
isInitialized bool
no setter
themeColor Color
no setter
themeData ThemeData
no setter