AppNavigation class abstract

Implementers

Constructors

AppNavigation()

Properties

arguments → dynamic
no setter
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, String?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

back({dynamic result}) → void
bottomSheet(BuildContext context, {required Widget builder(BuildContext), bool? isScrollControlled, bool? enableDrag, bool? isDismissible}) Future
dialog(Widget widget, {bool barrierDismissible = true, Color? barrierColor, bool useSafeArea = true, GlobalKey<NavigatorState>? navigatorKey, Object? arguments, Duration? transitionDuration, Curve? transitionCurve, String? name, RouteSettings? routeSettings}) Future?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMaps({required double latitude, required double longitude}) Future
openPhoneCall({required String phoneNumber}) Future
openWhatsApp({required String phoneNumber, required String message}) Future
pushNamed(String routeName, {Map<String, String>? params, dynamic arguments, bool preventDuplicates = true}) Future?
pushNamedAndRemoveUntil(String routeName, {Map<String, String>? params, dynamic arguments, bool predicate(Route)?}) Future?
pushReplacementNamed(String routeName, {Map<String, String>? params, dynamic arguments, bool preventDuplicates = true}) Future?
removeUntil(String routeName, {Map<String, String>? params, dynamic arguments}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited