AuthNavigationValidator class abstract

Constructors

AuthNavigationValidator()
const

Properties

arguments → dynamic
no setter
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, String?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

backWithAuth({dynamic result}) → void
bottomSheetWithAuth(BuildContext context, {required Widget builder(BuildContext)}) Future
dialogWithAuth(Widget widget, {bool barrierDismissible = true, Color? barrierColor, bool useSafeArea = true, GlobalKey<NavigatorState>? navigatorKey, Object? arguments, Duration? transitionDuration, Curve? transitionCurve, String? name, RouteSettings? routeSettings}) Future?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMapsWithAuth({required double latitude, required double longitude}) Future
openPhoneCallWithAuth({required String phoneNumber}) Future
openWhatsAppWithAuth({required String phoneNumber, required String message}) Future
pushNamedAndRemoveUntilWithAuth(String routeName, {Map<String, String>? params, dynamic arguments}) Future?
pushNamedWithAuth(String routeName, {Map<String, String>? params, dynamic arguments, bool preventDuplicates = true}) Future?
pushReplacementNamedWithAuth(String routeName, {Map<String, String>? params, dynamic arguments, bool preventDuplicates = true}) Future?
removeUntilWithAuth(String routeName, {Map<String, String>? params, dynamic arguments}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited