APIException class

Implemented types
Implementers

Constructors

APIException(String prefix, String message, int? statusCode, int? errorCode, String? thirdpartyResponseDirectWebViewURL)

Properties

errorCode int?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
prefix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
thirdpartyResponseDirectWebViewURL String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited