UnauthorisedException class

Inheritance

Constructors

UnauthorisedException({required String message, required int? statusCode, int? errorCode, String? thirdpartyResponseDirectWebViewURL})

Properties

errorCode int?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
prefix String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
finalinherited
thirdpartyResponseDirectWebViewURL String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited