Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete({required String url, Map<String, dynamic>? queryParameters, Map<String, dynamic>? requestBody, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future<Map<String, dynamic>>
-
-
fileWithGet({required String url, Map<String, dynamic>? queryParameters, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future
-
-
fileWithPost({required String url, Map<String, dynamic>? queryParameters, Map<String, dynamic>? requestBody, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future
-
-
get({required String url, Map<String, dynamic>? queryParameters, bool? withToken, bool? withTokenBasic, bool isUrlPG = false, required bool withAccessToken})
→ Future<Map<String, dynamic>>
-
-
google({required String url, Map<String, dynamic>? queryParameters, Map<String, dynamic>? requestBody, GoogleType type = GoogleType.GET, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future<Map<String, dynamic>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch({required String url, Map<String, dynamic>? queryParameters, Map<String, dynamic>? requestBody, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future<Map<String, dynamic>>
-
-
post({required String url, Map<String, dynamic>? queryParameters, Map<String, dynamic>? requestBody, bool? withToken, bool? withTokenBasic, bool isUrlPG = false, bool? withAccessToken})
→ Future<Map<String, dynamic>>
-
-
postDynamic({required String url, Map<String, dynamic>? queryParameters, dynamic requestBody, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future<Map<String, dynamic>>
-
-
postMultipart({required String url, Map<String, dynamic>? queryParameters, required Map<String, dynamic> body, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future<Map<String, dynamic>>
-
-
put({required String url, Map<String, dynamic>? queryParameters, Map<String, dynamic>? requestBody, bool? withToken, bool? withTokenBasic, bool isUrlPG = false})
→ Future<Map<String, dynamic>>
-
-
toString()
→ String
-
A string representation of this object.
inherited