ValidataSDKRequest class
Constructors
- ValidataSDKRequest({String? sdkKey, String? merchantId, String? merchantName, String? userEmail, String? userFullName, String? userPhoneNumber})
-
ValidataSDKRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantId ↔ String
-
getter/setter pair
- merchantName ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkKey ↔ String
-
getter/setter pair
- userEmail ↔ String
-
getter/setter pair
- userFullName ↔ String
-
getter/setter pair
- userPhoneNumber ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited