DeliveryMethodSheet class

Inheritance
Available extensions

Constructors

DeliveryMethodSheet({Key? key, required String orderId, int? productID, int? skuID, int? orderItemId, required int storeId, required LatLong location, required List<OrderItems> orderItems, bool isOrderDeliv = false, String? skuCode, required CartController controller})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isOrderDeliv bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
location LatLong
final
marginZero Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
orderId String
final
orderItemId int?
final
orderItems List<OrderItems>
final
paddingZero Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
productID int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skuCode String?
final
skuID int?
final
sliverBox Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
storeId int
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEditMethodClick(BuildContext context, String deliveryOpt, [bool isMissing = false]) → void
onSavedClick() → void
paddingAll(double padding) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
trailing(BuildContext context, String selectedPosition, String meaning) Widget?

Operators

operator ==(Object other) bool
The equality operator.
inherited