CheckoutController class

Inheritance

Constructors

CheckoutController({required PaymentService paymentService, required LookupService lookupService, required ShippingService shippingService, required ProfileService profileService, required ProductService productService, required HistoryService historyService})

Properties

arg CheckoutArgs?
getter/setter pair
canGoBack bool
getter/setter pair
canUsePoint bool
getter/setter pair
defaultPointEligible int
getter/setter pair
deliveryOpt List<DropdownOption<int>>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
historyService HistoryService
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isPageLoading RxBool
getter/setter pair
isPaymentLoading RxBool
getter/setter pair
isPickerOrder RxBool
getter/setter pair
isUsingBuySmartPoint RxBool
getter/setter pair
listeners int
no setterinherited
lookupDeliv List<Lookup>?
getter/setter pair
lookupService LookupService
final
membership MembershipPoint
getter/setter pair
onDelete InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onError MsgCallback?
getter/setter pair
onPointWarning MsgCallback?
getter/setter pair
onStart InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
onSuccess MsgCallback?
getter/setter pair
paymentResp CheckoutConfirm?
getter/setter pair
paymentService PaymentService
final
pointErrorMsg String
getter/setter pair
pointsReceived RxInt
getter/setter pair
pointValue int
getter/setter pair
productService ProductService
final
profile Profile
getter/setter pair
profileService ProfileService
final
receiptArg Rx<ViewData<ReceiptArg>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDeliveryCode String
getter/setter pair
shippingCoverage ViewData<ShippingCoverageCheck>
getter/setter pair
shippingService ShippingService
final
showUsePoint bool
getter/setter pair
submitModel Checkout
getter/setter pair
totalPay RxDouble
getter/setter pair
totalPointUsed int
getter/setter pair
totalPointValued double
getter/setter pair
validateDelivery bool
getter/setter pair
validateDeliveryStore bool
getter/setter pair
validateInstant bool
getter/setter pair
validatePickup bool
getter/setter pair
validateRegular bool
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
addPointPriceDetail() → dynamic
assignDeliveries({bool isUpdate = false, String? orderGroupID}) → dynamic
calculateTotal({bool reload = true, String? orderGroupID}) → dynamic
changeRegShipSummary({required ShippingSummary model, String? orderGroupID}) → dynamic
checkShipment(ScrollController scrollController) String
confirmCheckout({required dynamic onCheckoutError(String error)?}) Future<String?>
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
generateOptions() List<DropdownOption<int>>
getCart(String? orderGroupId) Future<void>
getDefaultPointEligible() → dynamic
getProfile() → dynamic
getShippingCoverage(int storeId) Future<void>
mapCartToUpdateCartRequest() List<DataListRequest>
mapToModel({required Checkout model, String? orderGroupID}) → dynamic
memberPoints() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onlineHistorySearch() Future<void>
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
poinInquiry() → dynamic
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
scrollUp(ScrollController scrollController) → dynamic
searchLookup() → dynamic
setSelectedAddressPos(String val) → void
setTotalPoint() → dynamic
showPoinValue() → dynamic
submitBluPay() Future<void>
subTitleDeliveryMethod() String
switchIsPickerOrder() → void
switchUsingBuySmartPoint({required bool val, String? orderGroupID}) → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateDeliveryShip(ShippingSummary shipping, StoreDetail storeDetail, Pricings? shipmentPricing, int orderIndex, int summaryIndex, {String? orderGroupID}) → dynamic
updateInstantDeliv(ShippingSummary shipping, StoreDetail storeDetail, Pricings? shipmentPricing, int orderIndex, int summaryIndex, {String? orderGroupID}) → dynamic
updateRegShip(ShippingSummary shipping, StoreDetail storeDetail, Pricings? shipmentPricing, int orderIndex, int summaryIndex, {String? orderGroupID}) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited