PaymentMethodArg class

Constructors

PaymentMethodArg({String? orderGroupID, String? callBackRouteName, dynamic onRequestPaymentCompleted(CheckoutPayment result)?, dynamic onError(String error)?, dynamic onResultPaymentClosePressed()?, dynamic onRetryPaymentPressed()?, dynamic onChangePaymentPressed()?, dynamic onPaymentProcessCompleted(IncommePaymentStatus result)?})

Properties

callBackRouteName String?
final
hashCode int
The hash code for this object.
no setterinherited
onChangePaymentPressed → dynamic Function()?
final
onError → dynamic Function(String error)?
final
onPaymentProcessCompleted → dynamic Function(IncommePaymentStatus result)?
final
onRequestPaymentCompleted → dynamic Function(CheckoutPayment result)?
final
onResultPaymentClosePressed → dynamic Function()?
final
onRetryPaymentPressed → dynamic Function()?
final
orderGroupID String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited