PaymentMethod class

Constructors

PaymentMethod({PriceSummary? priceSummary, List<PaymentChannels>? channels})
const
PaymentMethod.fromJson(Map json)
factory

Properties

channels List<PaymentChannels>
final
hashCode int
The hash code for this object.
no setterinherited
priceSummary PriceSummary
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<PaymentChannels>? channels}) PaymentMethod
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sort() SortedPaymentMethod
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited