PriceSummary class
Constructors
- PriceSummary({String? totalPrice, String? totalFormattedPrice})
-
const
- PriceSummary.fromJson(Map map)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalFormattedPrice → String
-
final
- totalPrice → String
-
final
Methods
-
copyWith(
{String? totalPrice, String? totalFormattedPrice}) → PriceSummary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited