PaymentParameter class

Constructors

PaymentParameter({String? paymentCode, String? expiredDate, num? total, String? merchantId, String? merchantTranId, String? currencyCode, String? intAmount, String? custName, String? custEmail, String? returnUrl, String? paymentMethodStr, String? transactionTypeStr, String? signature, int? paymentMethodInt, int? transactionTypeInt, String? token, String? refNumber, String? orderId, String? customerName, String? customerPhone, String? customerEmail, String? description, String? pgProcessingId, String? transactionReference, String? orderCreated, String? orderExpired, num? status, String? signatureBluePay, String? transactionId, String? imageUrl, double? doubleAmount})
const
PaymentParameter.fromJson(Map json)
factory

Properties

currencyCode String
final
custEmail String
final
custName String
final
customerEmail String
final
customerName String
final
customerPhone String
final
description String
final
doubleAmount double
final
expiredDate String
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
intAmount String
final
merchantId String
final
merchantTranId String
final
orderCreated String
final
orderExpired String
final
orderId String
final
paymentCode String
final
paymentMethodInt int
final
paymentMethodStr String
final
pgProcessingId String
final
refNumber String
final
returnUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
final
signatureBluePay String
final
status num
final
token String
final
total num
final
transactionId String
final
transactionReference String
final
transactionTypeInt int
final
transactionTypeStr String
final

Methods

copyWith({String? paymentCode, String? expiredDate, num? total, String? merchantId, String? merchantTranId, String? currencyCode, String? intAmount, String? custName, String? custEmail, String? returnUrl, String? paymentMethodStr, String? transactionTypeStr, String? signature, int? paymentMethodInt, int? transactionTypeInt, String? token, String? refNumber, String? orderId, String? customerName, String? customerPhone, String? customerEmail, String? description, String? pgProcessingId, String? transactionReference, String? orderCreated, String? orderExpired, num? status, String? signatureBluePay, String? transactionId, String? imageUrl, double? doubleAmount}) PaymentParameter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited