IncommePaymentMethodController class

Inheritance

Constructors

IncommePaymentMethodController(PaymentService paymentService)

Properties

ccState Rx<ViewData<CheckoutPayment>>
getter/setter pair
channels List<PaymentChannels>
getter/setter pair
channelState Rx<ViewData<PaymentMethod>>
getter/setter pair
checkout Checkout
getter/setter pair
eWalletState Rx<ViewData<CheckoutPayment>>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
inPersonState Rx<ViewData<CheckoutPayment>>
getter/setter pair
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isSearchMode RxBool
final
isTyping bool
getter/setter pair
listeners int
no setterinherited
onDelete InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
paymentService PaymentService
final
priceSummary PriceSummary
getter/setter pair
qrisState Rx<ViewData<CheckoutPayment>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchController TextEditingController
final
searchList List<PaymentChannels>
getter/setter pair
searchVal String
getter/setter pair
vaState Rx<ViewData<CheckoutPayment>>
getter/setter pair
viewState Rx<ViewData<SortedPaymentMethod>>
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
checkoutPaymentCC(CheckoutPaymentReq request) → dynamic
checkoutPaymentEwallet(CheckoutPaymentReq request) Future<void>
checkoutPaymentInPerson(CheckoutPaymentReq request) → dynamic
checkoutPaymentQris(CheckoutPaymentReq request) → dynamic
checkPaymentPG(CheckoutPaymentReq request) → dynamic
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getPaymentMethod(String orderGroupID) → dynamic
isAllEmpty() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onSearchChanged(String keyword) → dynamic
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
reload(String orderGroupID) → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
toggleSearchMode() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited