AddressService class abstract

Implementers

Constructors

AddressService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addressDetail(int id) Future<Either<Failure, Address>>
distanceMatrix({Map<String, dynamic>? param}) Future<Either<Failure, AddressMatrix>>
listAddress({int? branchID}) Future<Either<Failure, List<Address>>>
listCity(int provinceID) Future<Either<Failure, List<City>>>
listCountry() Future<Either<Failure, List<Country>>>
listDistrict(int cityID) Future<Either<Failure, List<District>>>
listPostalCode(int districtID) Future<Either<Failure, List<PostalCode>>>
listProvince(int countryID) Future<Either<Failure, List<Province>>>
listSubDistrict(int districtID) Future<Either<Failure, List<SubDistrict>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveAddress(Map<String, dynamic> body) Future<Either<Failure, Address>>
setAddress({Map<String, dynamic>? param}) Future<Either<Failure, Address>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited