AddressServiceImpl class

Implemented types

Constructors

AddressServiceImpl(HttpHandler apiService)

Properties

apiService HttpHandler
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addressDetail(int id) Future<Either<Failure, Address>>
override
distanceMatrix({Map<String, dynamic>? param}) Future<Either<Failure, AddressMatrix>>
override
listAddress({int? branchID}) Future<Either<Failure, List<Address>>>
override
listCity(int provinceID) Future<Either<Failure, List<City>>>
override
listCountry() Future<Either<Failure, List<Country>>>
override
listDistrict(int cityID) Future<Either<Failure, List<District>>>
override
listPostalCode(int districtID) Future<Either<Failure, List<PostalCode>>>
override
listProvince(int countryID) Future<Either<Failure, List<Province>>>
override
listSubDistrict(int districtID) Future<Either<Failure, List<SubDistrict>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveAddress(Map<String, dynamic> body) Future<Either<Failure, Address>>
override
setAddress({Map<String, dynamic>? param}) Future<Either<Failure, Address>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited