NotificationServiceImpl class

Implemented types

Constructors

NotificationServiceImpl(HttpHandler _httpHandler)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getNotificationList() Future<Either<Failure, List<NotificationItem>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited