ProfileServiceImpl class

Implemented types

Constructors

ProfileServiceImpl(HttpHandler httpHandler)

Properties

hashCode int
The hash code for this object.
no setterinherited
httpHandler HttpHandler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProfile() Future<Either<Failure, Profile>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateProfile({required Profile model}) Future<Either<Failure, Profile>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited