ScannerService class abstract

Implementers

Constructors

ScannerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmScanInTransit({required int branchId, required int transitId, required List<int> cartId}) Future<Either<Failure, ScanInStoreResult>>
getScanInTransit({required int branchID}) Future<Either<Failure, ScanInStoreResult>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTrolley({required int branchId, required int barcodeId}) Future<Either<Failure, ScanInStoreResult>>
scan({required int branchID, required String code, required double latitude, required double longitude}) Future<Either<Failure, ScanResult>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited