UploadServiceImpl class

Implemented types

Constructors

UploadServiceImpl(HttpHandler httpHandler)

Properties

hashCode int
The hash code for this object.
no setterinherited
httpHandler HttpHandler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postUpload({required Map<String, dynamic> body}) Future<Either<Failure, FileModel>>
override
saveUpload({required Map<String, dynamic> body}) Future<Either<Failure, SaveFile>>
override
toString() String
A string representation of this object.
inherited
upload({required Map<String, dynamic> body}) Future<Either<Failure, FileModel>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited