ColorName class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

appBlack → const Color
Color: #000000
appWhite → const Color
Color: #ffffff
black70 → const Color
Color: #1A1A1A
blue → const Color
Color: #31C3E4
cream → const Color
Color: #FFE4D9
cream2 → const Color
Color: #FBF4EA
dividerGray → const Color
Color: #E2E3E5
gold → const Color
Color: #E8A545
gray → const Color
Color: #BDBDBD
gray2 → const Color
Color: #ACA5A5
gray3 → const Color
Color: #B1B4B7
gray5 → const Color
Color: #FBF9F8
gray6 → const Color
Color: #F2F2F2
gray7 → const Color
Color: #E0E0E0
gray8 → const Color
Color: #828282
gray9 → const Color
Color: #D9D9D9
green → const Color
Color: #27AE60
grey4 → const Color
Color: #BDBDBD
maroon → const Color
Color: #80151A
orange → const Color
Color: #EA5317
pink → const Color
Color: #FFC8D3
pink2 → const Color
Color: #FFE1E7
pricingGreen → const Color
Color: #99C45F
redMain → const Color
Color: #2B498D
snowGray → const Color
Color: #E6E7E8
snowGray2 → const Color
Color: #EEEFF0
splashMain → const Color
sweetPink → const Color
Color: #FFEEF1
yellow → const Color
Color: #E8A545