IncommeTextStyle class

Constructors

IncommeTextStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bodyBold TextStyle
getter/setter pair
bodyMedium TextStyle
getter/setter pair
bodyRegular TextStyle
getter/setter pair
bodySemiBold TextStyle
getter/setter pair
bodyWhite TextStyle
getter/setter pair
font String
final
headingLarge TextStyle
getter/setter pair
plain TextStyle
getter/setter pair
semiBold TextStyle
getter/setter pair