IncomeThemeManager class
Constructors
- IncomeThemeManager()
-
factory
Properties
- appName → String
-
no setter
- fontFamilyName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- incommeThemeData → ThemeData
-
no setter
- logoUrl → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeColor → Color
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAppName(
String appName) → void -
setFontFamily(
IncommeFont fontFamily) → void -
setlogoUrl(
String url) → void -
setThemeColor(
String hexColor) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited