FileSaverApi class
Constructors
- FileSaverApi({BinaryMessenger? binaryMessenger})
-
Constructor for FileSaverApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestWriteExternalStoragePermission(
) → Future< bool?> -
In Android 5 return result of
ContextCompat.checkSelfPermissionFirstly, you need add permission into AndroidManifest.xml -
saveFile(
String argFilepath, String? argDestinationfilename) → Future< String?> - Silent saving file into:
-
saveFileWithDialog(
SaveFileDialogParams argParams) → Future< String?> - Save file through standard file saving dialog
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
codec
→ const MessageCodec<
Object?>