Logger class

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

d(String message, {dynamic ex, StackTrace? stacktrace}) → void
Logs DUBUG level message with optional exception and stacktrace
e(String message, {dynamic ex, StackTrace? stacktrace}) → void
Logs ERROR level message. Please fill ex (exception) and stacktrace so it will record them to Crashlytics.
i(String message, {dynamic ex, StackTrace? stacktrace}) → void
Logs INFO level message with optional exception and stacktrace
v(String message, {dynamic ex, StackTrace? stacktrace}) → void
Logs VERBOSE level message with optional exception and stacktrace
w(String message, {dynamic ex, StackTrace? stacktrace}) → void
Logs WARNING level message. Please fill ex (exception) and stacktrace so it will record them to Crashlytics.