ObserverState<T> class
Constructors
-
ObserverState({required ViewData<
T> state, dynamic onLoaded(T)?, dynamic onError(String, Failure?)?, dynamic onLoading()?, dynamic onInit()?}) - ObserverState.asListener({dynamic onLoaded(T)?, dynamic onError(String, Failure?)?, dynamic onLoading()?, dynamic onInit()?})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onError ↔ dynamic Function(String, Failure?)?
-
latefinal
- onInit ↔ dynamic Function()?
-
latefinal
- onLoaded ↔ dynamic Function(T)?
-
latefinal
- onLoading ↔ dynamic Function()?
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ ViewData<
T> -
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited