ObserverStateWidget<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ObserverStateWidget
- Available extensions
Constructors
-
ObserverStateWidget({Key? key, required ViewData<
T> state, required Widget onLoaded(T), required BuildContext context, T? initialValue, Widget onError(String)?, Widget onLoading()?, dynamic onReload()?, Widget others(ObserverStateWidget<T> , T?)?, ObserverState<T> ? onStateChanges, LifeCycleState<GetxController> ? lifeCycleState, bool isShowOverlapLoading = false, bool isShowOverlapError = false, bool isLoadingDismissAble = false, bool isShownError = true, bool enableAutoDismissLoading = true, bool isShowLoading = true}) -
const
Properties
- context → BuildContext
-
final
- enableAutoDismissLoading → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → T?
-
final
- isLoadingDismissAble → bool
-
final
- isShowLoading → bool
-
final
- isShownError → bool
-
final
- isShowOverlapError → bool
-
final
- isShowOverlapLoading → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
lifeCycleState
→ LifeCycleState<
GetxController> ? -
final
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter - onError → Widget Function(String)?
-
final
- onLoaded → Widget Function(T)
-
final
- onLoading → Widget Function()?
-
final
- onReload → dynamic Function()?
-
final
-
onStateChanges
→ ObserverState<
T> ? -
final
-
others
→ Widget Function(ObserverStateWidget<
T> , T?)? -
final
- paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter -
state
→ ViewData<
T> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
emitViewStateChanges(
ViewState state) → void -
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited