ViewData<T> class

Constructors

ViewData.empty()
factory
ViewData.error({required String message, Failure? failure})
factory
ViewData.initial()
factory
ViewData.loaded({T? data})
factory
ViewData.loading()
factory
ViewData.submitted({T? data})
factory

Properties

data ↔ T?
getter/setter pair
failure Failure?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ViewState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited