DevTree class

Constructors

DevTree({List<String> logLevels = defaultLevels, int printType = timeClockType, bool useColor = true})

Properties

colorizeMap Map<String, ColorizeStyle>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logLevels List<String>
final
printType int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useColor bool
final

Methods

getLevels() List<String>
Gets levels of logging serviced by this LogTree
log(String level, String message, {String? tag, dynamic ex, StackTrace? stacktrace}) → void
Logs message with log level and optional tag, ex (exception) stacktrace
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printLog(String logLine, {String? logLevel}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultLevels → const List<String>
timeClockType → const int