AppSizer class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getDeviceResolution(
BuildContext context) → String -
getFixedSizeOf(
BuildContext context, double size, {double? tabletSize}) → double -
getHeightSizeOf(
BuildContext context, double size, {double? tabletSize}) → double -
getTextSize(
BuildContext context, double size, {double? tabletSize, bool isFixedSize = false}) → double -
getWidthSizeOf(
BuildContext context, double size, {double? tabletSize}) → double -
isMobile(
BuildContext context) → bool -
isSmallDeviceByResolution(
BuildContext context) → bool -
isSmallPhone(
BuildContext context) → bool -
isTableRatio(
BuildContext context) → bool -
isTablet(
BuildContext context) → bool