Checkout class
Constructors
-
Checkout({double? quantity, double? quantityRemains, double? subtotal, double? total, List<
ShippingSummary> ? regularShippingSummary, List<ShippingSummary> ? deliveryStoreShippingSummaryList, List<Pickup> ? pickup, List<ShippingSummary> ? instantDeliverySummary, List<GreetingCardSummary> ? greetingCardSummary, List<OrderLists> ? orderLists, List<OrderDiscount> ? orderDiscounts, CouponSummary? couponSummary, List<PriceDetail> ? priceDetail, VoucherSummary? voucherSummary, bool? hasPickUp, bool? hasRegular, bool? hasDeliveryStore, bool? hasInstantDelivery, String? orderGroupID, String? expiredPaymentDate, double? totalDiscount, double? totalShippingCost, double? discountShippingCost, double? pointInquiry, int? totalProduct, OrderAddress? orderAddress, bool? declinedLoginBeforeCheckout, bool? shippingAndTaxesProcessed, bool? isRegularShipping, bool? isPickupDelivery, bool? isInstantDelivery, LoyaltiSummary? loyaltiSummary, BillingInformation? billingInformation, int? isOrderHistory}) - Checkout.map(Map obj)
-
factory
Properties
- billingInformation ↔ BillingInformation
-
getter/setter pair
- couponSummary ↔ CouponSummary
-
getter/setter pair
- declinedLoginBeforeCheckout ↔ bool
-
getter/setter pair
-
deliveryStoreShippingSummaryList
↔ List<
ShippingSummary> -
getter/setter pair
- discountShippingCost ↔ double
-
getter/setter pair
- expiredPaymentDate ↔ String
-
getter/setter pair
- expiredPaymentDT ↔ DateTime
-
getter/setter pair
-
getDataListRequest
→ List<
DataListRequest> -
no setter
-
greetingCardSummary
↔ List<
GreetingCardSummary> -
getter/setter pair
- hasDeliveryStore ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInstantDelivery ↔ bool
-
getter/setter pair
- hasPickUp ↔ bool
-
getter/setter pair
- hasRegular ↔ bool
-
getter/setter pair
-
instantDeliverySummary
↔ List<
ShippingSummary> -
getter/setter pair
- isInstantDelivery ↔ bool
-
getter/setter pair
- isOrderHistory ↔ int
-
getter/setter pair
- isPickupDelivery ↔ bool
-
getter/setter pair
- isRegularShipping ↔ bool
-
getter/setter pair
- loyaltiSummary ↔ LoyaltiSummary
-
getter/setter pair
- orderAddress ↔ OrderAddress
-
getter/setter pair
-
orderDiscounts
↔ List<
OrderDiscount> -
getter/setter pair
- orderGroupID ↔ String
-
getter/setter pair
-
orderLists
↔ List<
OrderLists> -
getter/setter pair
-
pickup
↔ List<
Pickup> -
getter/setter pair
- pointInquiry ↔ double
-
getter/setter pair
-
priceDetail
↔ List<
PriceDetail> -
getter/setter pair
- quantity ↔ double
-
getter/setter pair
- quantityRemains ↔ double
-
getter/setter pair
-
regularShippingSummary
↔ List<
ShippingSummary> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAndTaxesProcessed ↔ bool
-
getter/setter pair
- subtotal ↔ double
-
getter/setter pair
- toJson → String
-
no setter
- total ↔ double
-
getter/setter pair
- totalDiscount ↔ double
-
getter/setter pair
- totalProduct ↔ int
-
getter/setter pair
- totalShippingCost ↔ double
-
getter/setter pair
- voucherSummary ↔ VoucherSummary
-
getter/setter pair
Methods
-
copyWith(
{double? quantity, double? quantityRemains, double? subtotal, double? total, List< ShippingSummary> ? regularShippingSummary, List<ShippingSummary> ? deliveryStoreShippingSummaryList, List<Pickup> ? pickup, List<ShippingSummary> ? instantDeliverySummary, List<GreetingCardSummary> ? greetingCardSummary, List<OrderLists> ? orderLists, List<OrderDiscount> ? orderDiscounts, CouponSummary? couponSummary, List<PriceDetail> ? priceDetail, VoucherSummary? voucherSummary, bool? hasPickUp, bool? hasRegular, bool? hasDeliveryStore, bool? hasInstantDelivery, String? orderGroupID, String? expiredPaymentDate, double? totalDiscount, double? totalShippingCost, double? discountShippingCost, double? pointInquiry, int? totalProduct, OrderAddress? orderAddress, bool? declinedLoginBeforeCheckout, bool? shippingAndTaxesProcessed, bool? isRegularShipping, bool? isPickupDelivery, bool? isInstantDelivery, LoyaltiSummary? loyaltiSummary, BillingInformation? billingInformation, int? isOrderHistory}) → Checkout -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited