OrderItemAttributes class
Constructors
- OrderItemAttributes({String? attributeCode, String? attributeName, String? attributeValue, String? optionCode, String? optionName})
- OrderItemAttributes.map(Map obj)
-
factory
Properties
- attributeCode ↔ String
-
getter/setter pair
- attributeName ↔ String
-
getter/setter pair
- attributeValue ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- optionCode ↔ String
-
getter/setter pair
- optionName ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? attributeCode, String? attributeName, String? attributeValue, String? optionCode, String? optionName}) → OrderItemAttributes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited