$AssetsImagesGen class
Constructors
- $AssetsImagesGen()
-
const
Properties
- background → $AssetsImagesBackgroundGen
-
Directory path: assets/images/background
no setter
- category → AssetGenImage
-
File path: assets/images/category.png
no setter
- decoration → $AssetsImagesDecorationGen
-
Directory path: assets/images/decoration
no setter
- emptyWishlist → AssetGenImage
-
File path: assets/images/empty_wishlist.png
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- illustration → $AssetsImagesIllustrationGen
-
Directory path: assets/images/illustration
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
AssetGenImage> -
List of all assets
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited