NotificationItem class
Constructors
- NotificationItem({required String? androidClick, required String? apnsClick, required String? header, required String? subheader, required String? body, required String? category, required String? urlPath, required int? notificationId, required int? isUserRead, required DateTime? createdDate})
-
NotificationItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- androidClick → String?
-
final
- apnsClick → String?
-
final
- body → String?
-
final
- category → String?
-
final
- createdDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → String?
-
final
- isUserRead → int?
-
final
- notificationId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subheader → String?
-
final
- urlPath → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited