PaymentMethodDto class
Constructors
-
PaymentMethodDto({required bool? success, required String? error, required PaymentMethodResp? model, required List<
String> ? errors, required List<String> ? errorCodes, required List<String> ? messageCodes, required List<String> ? messages}) - PaymentMethodDto.fromJson(Map json)
-
factory
Properties
- error → String?
-
final
-
errorCodes
→ List<
String> ? -
final
-
errors
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messageCodes
→ List<
String> ? -
final
-
messages
→ List<
String> ? -
final
- model → PaymentMethodResp?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited