AddressMatrix class
Constructors
- AddressMatrix({String? sourceLatitude, String? sourceLongitude, String? destinationLatitude, String? destinationLongitude, double? distance})
-
AddressMatrix.map(Map<
String, dynamic> obj) -
factory
Properties
- destinationLatitude ↔ String
-
getter/setter pair
- destinationLongitude ↔ String
-
getter/setter pair
- distance ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceLatitude ↔ String
-
getter/setter pair
- sourceLongitude ↔ String
-
getter/setter pair
Methods
-
copyWith(
{String? sourceLatitude, String? sourceLongitude, String? destinationLatitude, String? destinationLongitude, double? distance}) → AddressMatrix -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
toSubmit(
) → Map< String, dynamic>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited