LocationHandler class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
determinePosition(
) → Future< Position> -
determinePositionTemp(
Future openSettingCallback()) → Future< Position> -
getIOSLocation(
{required dynamic showSheet(), required dynamic showSettings()}) → Future< LatLong> -
getLocations(
) → Future< LatLong> -
getLocationTemp(
{required Future openSettingCallback(), required dynamic onDefaultCallback(String)}) → Future< LatLong> -
isDenied(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermission(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultLocation → LatLong
-
Summarecon Mall Kelapa Gading location
no setter